@@ -1,20 +1,7 @@
 package Image::Magick;
 
-#  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
-#  dedicated to making software imaging solutions freely available.
-#
-#  You may not use this file except in compliance with the License.  You may
-#  obtain a copy of the License at
-#
-#    https://imagemagick.org/script/license.php
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-#
-#  Initial version, written by Kyle Shorter.
+# Released Feb. 17, 1997  by Kyle Shorter (magick@wizards.dupont.com)
+# Public Domain
 
 use strict;
 use Carp;
@@ -43,13 +30,12 @@ require AutoLoader;
       ConfigureError FatalErrorException
     );
 
-$VERSION = '6.9.11';
+$VERSION = '6.71';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.  If a constant is not found then control is passed
     # to the AUTOLOAD in AutoLoader.
-    no warnings;
 
     my $constname;
     ($constname = $AUTOLOAD) =~ s/.*:://;
@@ -102,7 +88,7 @@ __END__
 
 =head1 NAME
 
-Image::Magick - objected-oriented Perl interface to ImageMagick. Use it to create, edit, compose, or convert bitmap images from within a Perl script.
+Image::Magick - objected-oriented Perl interface to ImageMagick. Use it to read, manipulate, or write an image or image sequence from within a Perl script.
 
 =head1 SYNOPSIS
 
@@ -123,12 +109,12 @@ It was originally developed to be used by CGI scripts for Web pages.
 
 A web page has been set up for this extension. See:
 
-	 file:///usr/share/doc/ImageMagick-6/www/perl-magick.html
-	 https://legacy.imagemagick.org/script/perl-magick.php
+	 file:///usr/local/share/doc/ImageMagick-6.7.1/www/perl-magick.html
+	 http://www.imagemagick.org/script/perl-magick.php
 
 If you have problems, go to
 
-   https://github.com/ImageMagick/ImageMagick6/issues
+   http://www.imagemagick.org/discourse-server/viewforum.php?f=7
 
 =head1 AUTHOR
 
