@@ -1,4 +1,4 @@
-#!/usr/local/bin/perl
+#!/usr/bin/perl
 #
 # Overall demo of the major PerlMagick methods.
 #
@@ -17,34 +17,47 @@ $model=Image::Magick->new();
 $x=$model->ReadImage('model.gif');
 warn "$x" if "$x";
 $model->Label('Magick');
-$model->Set(bordercolor=>'black');
-$model->Set(background=>'black');
+$model->Set(background=>'white');
 
 $smile=Image::Magick->new;
 $x=$smile->ReadImage('smile.gif');
 warn "$x" if "$x";
 $smile->Label('Smile');
-$smile->Set(bordercolor=>'black');
+$smile->Set(background=>'white');
 #
 # Create image stack.
 #
 print "Transform image...\n";
 $images=Image::Magick->new();
-$example=$null->Clone();
+
+print "Adaptive Blur...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Blur');
+$example->AdaptiveBlur('0x1');
 push(@$images,$example);
-$example=$null->Clone();
+
+print "Adaptive Resize...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Resize');
+$example->AdaptiveResize('60%');
 push(@$images,$example);
-$example=$null->Clone();
+
+print "Adaptive Sharpen...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Sharpen');
+$example->AdaptiveSharpen('0x1');
 push(@$images,$example);
-$example=$null->Clone();
-push(@$images,$example);
-$example=$null->Clone();
+
+print "Adaptive Threshold...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Threshold');
+$example->AdaptiveThreshold('5x5+5%');
 push(@$images,$example);
 
 print "Add Noise...\n";
 $example=$model->Clone();
 $example->Label('Add Noise');
-$example->AddNoise("LaplacianNoise");
+$example->AddNoise("Laplacian");
 push(@$images,$example);
 
 print "Annotate...\n";
@@ -54,6 +67,18 @@ $example->Annotate(text=>'Magick',geometry=>'+0+20',font=>'Generic.ttf',
   fill=>'gold',gravity=>'North',pointsize=>14);
 push(@$images,$example);
 
+print "Auto-gamma...\n";
+$example=$model->Clone();
+$example->Label('Auto Gamma');
+$example->AutoGamma();
+push(@$images,$example);
+
+print "Auto-level...\n";
+$example=$model->Clone();
+$example->Label('Auto Level');
+$example->AutoLevel();
+push(@$images,$example);
+
 print "Blur...\n";
 $example=$model->Clone();
 $example->Label('Blur');
@@ -69,13 +94,19 @@ push(@$images,$example);
 print "Channel...\n";
 $example=$model->Clone();
 $example->Label('Channel');
-$example->Channel();
+$example->Channel(channel=>'red');
 push(@$images,$example);
 
 print "Charcoal...\n";
 $example=$model->Clone();
 $example->Label('Charcoal');
-$example->Charcoal();
+$example->Charcoal('0x1');
+push(@$images,$example);
+
+print "ColorMatrix...\n";
+$example=$model->Clone();
+$example->Label('ColorMatrix');
+$example->ColorMatrix([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
 push(@$images,$example);
 
 print "Composite...\n";
@@ -90,6 +121,12 @@ $example->Label('Contrast');
 $example->Contrast();
 push(@$images,$example);
 
+print "Contrast Stretch...\n";
+$example=$model->Clone();
+$example->Label('Contrast Stretch');
+$example->ContrastStretch('5%');
+push(@$images,$example);
+
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
@@ -100,6 +137,7 @@ print "Crop...\n";
 $example=$model->Clone();
 $example->Label('Crop');
 $example->Crop(geometry=>'80x80+25+50');
+$example->Set(page=>'0x0+0+0');
 push(@$images,$example);
 
 print "Despeckle...\n";
@@ -108,6 +146,12 @@ $example->Label('Despeckle');
 $example->Despeckle();
 push(@$images,$example);
 
+print "Distort...\n";
+$example=$model->Clone();
+$example->Label('Distort');
+$example->Distort(method=>'arc',points=>[60],'virtual-pixel'=>'white');
+push(@$images,$example);
+
 print "Draw...\n";
 $example=$model->Clone();
 $example->Label('Draw');
@@ -124,10 +168,10 @@ push(@$images,$example);
 print "Emboss...\n";
 $example=$model->Clone();
 $example->Label('Emboss');
-$example->Emboss();
+$example->Emboss('0x1');
+push(@$images,$example);
 
 print "Equalize...\n";
-push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Equalize');
 $example->Equalize();
@@ -136,7 +180,6 @@ push(@$images,$example);
 print "Implode...\n";
 $example=$model->Clone();
 $example->Label('Explode');
-$example->Set(background=>'#000000FF');
 $example->Implode(-1);
 push(@$images,$example);
 
@@ -158,6 +201,11 @@ $example->Label('Frame');
 $example->Frame('15x15+3+3');
 push(@$images,$example);
 
+print "Fx...\n";
+$example=$model->Clone();
+$example->Label('Fx');
+push(@$images,$example->Fx(expression=>'0.5*u'));
+
 print "Gamma...\n";
 $example=$model->Clone();
 $example->Label('Gamma');
@@ -181,7 +229,7 @@ push(@$images,$gradient);
 print "Grayscale...\n";
 $example=$model->Clone();
 $example->Label('Grayscale');
-$example->Quantize(colorspace=>'gray');
+$example->Set(type=>'grayscale');
 push(@$images,$example);
 
 print "Implode...\n";
@@ -193,7 +241,7 @@ push(@$images,$example);
 print "Level...\n";
 $example=$model->Clone();
 $example->Label('Level');
-$example->Border(level=>'20%');
+$example->Level('20%');
 push(@$images,$example);
 
 print "Median Filter...\n";
@@ -210,10 +258,23 @@ push(@$images,$example);
 $example=$model->Clone();
 
 print "Monochrome...\n";
+$example=$model->Clone();
 $example->Label('Monochrome');
 $example->Quantize(colorspace=>'gray',colors=>2,dither=>'false');
 push(@$images,$example);
 
+print "Morphology...\n";
+$example=$model->Clone();
+$example->Label('Morphology');
+$example->Morphology(method=>'Dilate',kernel=>'Diamond',iterations=>3);
+push(@$images,$example);
+
+print "Motion Blur...\n";
+$example=$model->Clone();
+$example->Label('Motion Blur');
+$example->MotionBlur('0x13+10-10');
+push(@$images,$example);
+
 print "Negate...\n";
 $example=$model->Clone();
 $example->Label('Negate');
@@ -240,12 +301,30 @@ warn "$x" if "$x";
 $plasma->Label('Plasma');
 push(@$images,$plasma);
 
+print "Polaroid...\n";
+$example=$model->Clone();
+$example->Label('Polaroid');
+$example->Polaroid(caption=>'Magick',rotate=>-5.0,gravity=>'center');
+push(@$images,$example);
+
+print "Posterize...\n";
+$example=$model->Clone();
+$example->Label('Posterize');
+$example->Posterize(5);
+push(@$images,$example);
+
 print "Quantize...\n";
 $example=$model->Clone();
 $example->Label('Quantize');
 $example->Quantize();
 push(@$images,$example);
 
+print "Radial Blur...\n";
+$example=$model->Clone();
+$example->Label('Radial Blur');
+$example->RadialBlur(10);
+push(@$images,$example);
+
 print "Raise...\n";
 $example=$model->Clone();
 $example->Label('Raise');
@@ -261,7 +340,7 @@ push(@$images,$example);
 print "Resize...\n";
 $example=$model->Clone();
 $example->Label('Resize');
-$example->Resize('50%');
+$example->Resize('60%');
 push(@$images,$example);
 
 print "Roll...\n";
@@ -274,7 +353,12 @@ print "Rotate...\n";
 $example=$model->Clone();
 $example->Label('Rotate');
 $example->Rotate(45);
-$example->Transparent(color=>'black');
+push(@$images,$example);
+
+print "Sample...\n";
+$example=$model->Clone();
+$example->Label('Sample');
+$example->Sample('60%');
 push(@$images,$example);
 
 print "Scale...\n";
@@ -310,8 +394,20 @@ push(@$images,$example);
 print "Shear...\n";
 $example=$model->Clone();
 $example->Label('Shear');
-$example->Shear('45x45');
-$example->Transparent(color=>'black');
+$example->Shear('-20x20');
+push(@$images,$example);
+
+print "Sketch...\n";
+$example=$model->Clone();
+$example->Label('Sketch');
+$example->Set(colorspace=>'Gray');
+$example->Sketch('0x20+120');
+push(@$images,$example);
+
+print "Sigmoidal Contrast...\n";
+$example=$model->Clone();
+$example->Label('Sigmoidal Contrast');
+$example->SigmoidalContrast("3x50%");
 push(@$images,$example);
 
 print "Spread...\n";
@@ -328,7 +424,6 @@ push(@$images,$example);
 
 print "Swirl...\n";
 $example=$model->Clone();
-$example->Set(background=>'#000000FF');
 $example->Label('Swirl');
 $example->Swirl(90);
 push(@$images,$example);
@@ -339,20 +434,25 @@ $example->Label('Unsharp Mask');
 $example->UnsharpMask('0.0x1.0');
 push(@$images,$example);
 
+print "Vignette...\n";
+$example=$model->Clone();
+$example->Label('Vignette');
+$example->Vignette('0x20');
+push(@$images,$example);
+
 print "Wave...\n";
 $example=$model->Clone();
 $example->Label('Wave');
-$example->Set(background=>'#000000FF');
 $example->Wave('25x150');
 push(@$images,$example);
 #
 # Create image montage.
 #
 print "Montage...\n";
-$montage=$images->Montage(geometry=>'130x194+10+5>',gravity=>'Center',
-  bordercolor=>'green',borderwidth=>1,tile=>'5x1000',compose=>'over',
-  background=>'#ffffff',font=>'Generic.ttf',pointsize=>18,fill=>'#600',
-  stroke=>'none');
+$montage=$images->Montage(geometry=>'128x160+8+4>',gravity=>'Center',
+  tile=>'5x+10+200',compose=>'over',background=>'#ffffff',
+  font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none',
+	shadow=>'true');
 
 $logo=Image::Magick->new();
 $logo->Read('logo:');
